fortune: Display random quotes
==============================

## Introduction

`fortune` is yet another implementation of the Unix-style `fortune` program
that displays a random message from a database of quotations. Conceptually,
it's similar to the BSD fortune program originally written by [Ken Arnold][].
Unlike Arnold's program, this version is written in [Python][] and should
run anywhere there's a Python interpreter.

For installation and usage instructions, please see the [web page][].

[Ken Arnold]: http://en.wikipedia.org/wiki/Ken_Arnold
[Python]: http://www.python.org/
[web page]: http://software.clapper.org/fortune/

## Copyright

Copyright &copy; 2008-2023 Brian M. Clapper

## License

Prior to version 1.1.1, *fortune* was released under a 3-clause BSD license.
From version 1.1.1 on, *fortune* is released under the Apache Software License,
version 2.0. See [the license file](LICENSE.md) and
<https://www.apache.org/licenses/LICENSE-2.0> for more details.
